==> haskell-input-parsers-0.1.0.1-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 input-parsers
version:              0.1.0.1
visibility:           public
id:                   input-parsers-0.1.0.1-JrYO65Ctrr61XSkENGZO7L
key:                  input-parsers-0.1.0.1-JrYO65Ctrr61XSkENGZO7L
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  58c3a1d93a92a836867fee9096532cb2
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/input-parsers-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/input-parsers-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/input-parsers-0.1.0.1
hs-libraries:         HSinput-parsers-0.1.0.1-JrYO65Ctrr61XSkENGZO7L
depends:
    attoparsec-0.13.2.4-JZoYjKctPXo3EQxEpGFo7r base-4.14.1.0
    binary-0.8.8.0 bytestring-0.10.12.0
    monoid-subclasses-1.0.1-2tiI50yFTgS2jMDMdcjfVA parsec-3.1.14.0
    parsers-0.12.10-G8vw14Y79BT8OsfNi6fXQ6 text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-input-parsers-0.1.0.1-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 input-parsers
version:              0.1.0.1
visibility:           public
id:                   input-parsers-0.1.0.1-L7mAa0l6Vps9vRZOfYXHVz
key:                  input-parsers-0.1.0.1-L7mAa0l6Vps9vRZOfYXHVz
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  41af34a1454eea69ed78facdbd32b6cf
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/input-parsers-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/input-parsers-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/input-parsers-0.1.0.1
hs-libraries:         HSinput-parsers-0.1.0.1-L7mAa0l6Vps9vRZOfYXHVz
depends:
    attoparsec-0.13.2.4-39TJgLEc6zy21miTrRuwax base-4.14.1.0
    binary-0.8.8.0 bytestring-0.10.12.0
    monoid-subclasses-1.0.1-I2zWBzh5mjSLRhTNe21fpo parsec-3.1.14.0
    parsers-0.12.10-43ztw6GhtPe3nDVgOMfgAs text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
